@@ -7,6 +7,274 @@ from ..lazy.with_model_info_batch_op import WithModelInfoBatchOp
 from ..lazy.with_train_info import WithTrainInfo
 
 
+class VectorElementwiseProductBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorElementwiseProductBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorElementwiseProductBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setScalingVector(self, val):
+        return self._add_param('scalingVector', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class VectorFunctionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorFunctionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorFunctionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFuncName(self, val):
+        return self._add_param('funcName', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setWithVariable(self, val):
+        return self._add_param('WithVariable', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class VectorImputerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorImputerModelInfoBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorImputerModelInfoBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+
+class VectorImputerPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorImputerPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorImputerPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+
+class VectorImputerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorImputerTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorImputerTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setFillValue(self, val):
+        return self._add_param('fillValue', val)
+
+    def setStrategy(self, val):
+        return self._add_param('strategy', val)
+
+
+class VectorInteractionBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorInteractionBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorInteractionBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class VectorMaxAbsScalerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMaxAbsScalerModelInfoBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorMaxAbsScalerModelInfoBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+
+class VectorMaxAbsScalerPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMaxAbsScalerPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorMaxAbsScalerPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+
+class VectorMaxAbsScalerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMaxAbsScalerTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorMaxAbsScalerTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+
+class VectorMinMaxScalerModelInfoBatchOp(BatchOperator, ExtractModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMinMaxScalerModelInfoBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorMinMaxScalerModelInfoBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+
+class VectorMinMaxScalerPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMinMaxScalerPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorMinMaxScalerPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+
+class VectorMinMaxScalerTrainBatchOp(BatchOperator, WithModelInfoBatchOp):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorMinMaxScalerTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorMinMaxScalerTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setMax(self, val):
+        return self._add_param('max', val)
+
+    def setMin(self, val):
+        return self._add_param('min', val)
+
+
+class VectorNearestNeighborPredictBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.VectorNearestNeighborPredictBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorNearestNeighborPredictBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setRadius(self, val):
+        return self._add_param('radius', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setTopN(self, val):
+        return self._add_param('topN', val)
+
+
+class VectorNearestNeighborTrainBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.similarity.VectorNearestNeighborTrainBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorNearestNeighborTrainBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setIdCol(self, val):
+        return self._add_param('idCol', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setTrainType(self, val):
+        return self._add_param('trainType', val)
+
+    def setMetric(self, val):
+        return self._add_param('metric', val)
+
+
 class VectorNormalizeBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.vector.VectorNormalizeBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -312,6 +580,38 @@ class VectorToKvBatchOp(BatchOperator):
         return self._add_param('reservedCols', val)
 
 
+class VectorToTensorBatchOp(BatchOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.VectorToTensorBatchOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorToTensorBatchOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setTensorDataType(self, val):
+        return self._add_param('tensorDataType', val)
+
+    def setTensorShape(self, val):
+        return self._add_param('tensorShape', val)
+
+
 class VectorToTripleBatchOp(BatchOperator):
     CLS_NAME = 'com.alibaba.alink.operator.batch.dataproc.format.VectorToTripleBatchOp'
     OP_TYPE = 'FUNCTION'
@@ -408,15 +708,6 @@ class Word2VecPredictBatchOp(BatchOperator):
     def setSelectedCol(self, val):
         return self._add_param('selectedCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
