@@ -1,16 +1,14 @@
 from .lazy_evaluation import pipe_j_lazy_to_py_callbacks
-from ..base import BatchOperatorWrapper, BatchOperator
+from ..base import BatchOperatorWrapper
+from ...common.types.bases.j_obj_wrapper import JavaObjectWrapper
 from ...common.types.conversion.java_method_call import auto_convert_java_type
 from ...common.types.conversion.type_converters import j_value_to_py_value
-from ...common.types.bases.j_obj_wrapper import JavaObjectWrapper
+from ...common.utils.printing import print_with_title
 
 
 class ExtractModelInfoBatchOp(JavaObjectWrapper):
-    def getModelInfoBatchOp(self):
-        return BatchOperatorWrapper(self.get_j_obj().getModelInfoBatchOp())
-
     def lazyPrintModelInfo(self, title=None):
-        self.lazyCollectModelInfo(lambda d: print(title, d, sep="\n") if title is not None else print(d))
+        return self.lazyCollectModelInfo(lambda d: print_with_title(d, title))
 
     @auto_convert_java_type
     def collectModelInfo(self):
@@ -22,3 +20,4 @@ class ExtractModelInfoBatchOp(JavaObjectWrapper):
             callbacks,
             j_value_to_py_value
         )
+        return self
