@@ -70,7 +70,10 @@ def setup_py_flink_env(gateway: JavaGateway, j_benv: object, j_senv: object) ->
     benv = ExecutionEnvironment(j_benv)
     senv = StreamExecutionEnvironment(j_senv)
     btenv = BatchTableEnvironment.create(benv)
-    stenv = StreamTableEnvironment.create(senv)
+
+    from pyflink.table import EnvironmentSettings
+    stenv_settings = EnvironmentSettings.new_instance().use_old_planner().in_streaming_mode().build()
+    stenv = StreamTableEnvironment.create(senv, environment_settings=stenv_settings)
     return benv, btenv, senv, stenv
 
 
