@@ -4,6 +4,179 @@
 from ..base import StreamOperator, BaseSinkStreamOp, BaseModelStreamOp
 
 
+class SoftmaxPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.classification.SoftmaxPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SoftmaxPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setPredictionDetailCol(self, val):
+        return self._add_param('predictionDetailCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorCol(self, val):
+        return self._add_param('vectorCol', val)
+
+
+class SplitStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.SplitStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SplitStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFraction(self, val):
+        return self._add_param('fraction', val)
+
+    def setRandomSeed(self, val):
+        return self._add_param('randomSeed', val)
+
+
+class SqlCmdStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.sql.SqlCmdStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(SqlCmdStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setAlias(self, val):
+        return self._add_param('alias', val)
+
+    def setCommand(self, val):
+        return self._add_param('command', val)
+
+
+class StandardScalerPredictStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.StandardScalerPredictStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StandardScalerPredictStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCols(self, val):
+        return self._add_param('outputCols', val)
+
+
+class StopWordsRemoverStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.StopWordsRemoverStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StopWordsRemoverStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setCaseSensitive(self, val):
+        return self._add_param('caseSensitive', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setStopWords(self, val):
+        return self._add_param('stopWords', val)
+
+
+class StratifiedSampleStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.StratifiedSampleStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StratifiedSampleStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setStrataCol(self, val):
+        return self._add_param('strataCol', val)
+
+    def setStrataRatios(self, val):
+        return self._add_param('strataRatios', val)
+
+    def setStrataRatio(self, val):
+        return self._add_param('strataRatio', val)
+
+
+class StreamingKMeansStreamOp(BaseModelStreamOp):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.clustering.StreamingKMeansStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(StreamingKMeansStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setHalfLife(self, val):
+        return self._add_param('halfLife', val)
+
+    def setPredictionCol(self, val):
+        return self._add_param('predictionCol', val)
+
+    def setTimeInterval(self, val):
+        return self._add_param('timeInterval', val)
+
+    def setPredictionClusterCol(self, val):
+        return self._add_param('predictionClusterCol', val)
+
+    def setPredictionDistanceCol(self, val):
+        return self._add_param('predictionDistanceCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class StringIndexerPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.StringIndexerPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -102,15 +275,6 @@ class SwingRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -172,6 +336,15 @@ class TFTableModelPredictStreamOp(BaseModelStreamOp):
     def setInputSignatureDefs(self, val):
         return self._add_param('inputSignatureDefs', val)
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setOutputSignatureDefs(self, val):
         return self._add_param('outputSignatureDefs', val)
 
@@ -195,15 +368,18 @@ class TensorFlow2StreamOp(StreamOperator):
         super(TensorFlow2StreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
     def setOutputSchemaStr(self, val):
         return self._add_param('outputSchemaStr', val)
 
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
     def setIntraOpParallelism(self, val):
         return self._add_param('intraOpParallelism', val)
 
-    def setMainScriptFile(self, val):
-        return self._add_param('mainScriptFile', val)
-
     def setNumPSs(self, val):
         return self._add_param('numPSs', val)
 
@@ -216,9 +392,6 @@ class TensorFlow2StreamOp(StreamOperator):
     def setSelectedCols(self, val):
         return self._add_param('selectedCols', val)
 
-    def setUserFiles(self, val):
-        return self._add_param('userFiles', val)
-
     def setUserParams(self, val):
         return self._add_param('userParams', val)
 
@@ -233,15 +406,18 @@ class TensorFlowStreamOp(StreamOperator):
         super(TensorFlowStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setMainScriptFile(self, val):
+        return self._add_param('mainScriptFile', val)
+
     def setOutputSchemaStr(self, val):
         return self._add_param('outputSchemaStr', val)
 
+    def setUserFiles(self, val):
+        return self._add_param('userFiles', val)
+
     def setIntraOpParallelism(self, val):
         return self._add_param('intraOpParallelism', val)
 
-    def setMainScriptFile(self, val):
-        return self._add_param('mainScriptFile', val)
-
     def setNumPSs(self, val):
         return self._add_param('numPSs', val)
 
@@ -254,9 +430,6 @@ class TensorFlowStreamOp(StreamOperator):
     def setSelectedCols(self, val):
         return self._add_param('selectedCols', val)
 
-    def setUserFiles(self, val):
-        return self._add_param('userFiles', val)
-
     def setUserParams(self, val):
         return self._add_param('userParams', val)
 
@@ -272,6 +445,32 @@ class TensorSerializeStreamOp(StreamOperator):
         pass
 
 
+class TensorToVectorStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.TensorToVectorStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(TensorToVectorStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setConvertMethod(self, val):
+        return self._add_param('convertMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class TextSimilarityPairwiseStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.similarity.TextSimilarityPairwiseStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -353,6 +552,93 @@ class TextSourceStreamOp(StreamOperator):
         return self._add_param('textCol', val)
 
 
+class ToMTableStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.ToMTableStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ToMTableStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
+class ToTensorStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.ToTensorStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ToTensorStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setTensorDataType(self, val):
+        return self._add_param('tensorDataType', val)
+
+    def setTensorShape(self, val):
+        return self._add_param('tensorShape', val)
+
+
+class ToVectorStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.ToVectorStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(ToVectorStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setHandleInvalidMethod(self, val):
+        return self._add_param('handleInvalidMethod', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+    def setVectorType(self, val):
+        return self._add_param('vectorType', val)
+
+
 class TokenizerStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.TokenizerStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -530,15 +816,6 @@ class UserCfItemsPerUserRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -565,15 +842,6 @@ class UserCfRateRecommStreamOp(BaseModelStreamOp):
     def setUserCol(self, val):
         return self._add_param('userCol', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -603,15 +871,6 @@ class UserCfSimilarUsersRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -644,15 +903,6 @@ class UserCfUsersPerItemRecommStreamOp(BaseModelStreamOp):
     def setK(self, val):
         return self._add_param('k', val)
 
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -686,6 +936,32 @@ class VectorAssemblerStreamOp(StreamOperator):
         return self._add_param('reservedCols', val)
 
 
+class VectorBiFunctionStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorBiFunctionStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorBiFunctionStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setBiFuncName(self, val):
+        return self._add_param('biFuncName', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setSelectedCols(self, val):
+        return self._add_param('selectedCols', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class VectorElementwiseProductStreamOp(StreamOperator):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorElementwiseProductStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -712,6 +988,35 @@ class VectorElementwiseProductStreamOp(StreamOperator):
         return self._add_param('reservedCols', val)
 
 
+class VectorFunctionStreamOp(StreamOperator):
+    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorFunctionStreamOp'
+    OP_TYPE = 'FUNCTION'
+
+    def __init__(self, *args, **kwargs):
+        kwargs['CLS_NAME'] = self.CLS_NAME
+        kwargs['OP_TYPE'] = self.OP_TYPE
+        super(VectorFunctionStreamOp, self).__init__(*args, **kwargs)
+        pass
+
+    def setFuncName(self, val):
+        return self._add_param('funcName', val)
+
+    def setSelectedCol(self, val):
+        return self._add_param('selectedCol', val)
+
+    def setWithVariable(self, val):
+        return self._add_param('WithVariable', val)
+
+    def setNumThreads(self, val):
+        return self._add_param('numThreads', val)
+
+    def setOutputCol(self, val):
+        return self._add_param('outputCol', val)
+
+    def setReservedCols(self, val):
+        return self._add_param('reservedCols', val)
+
+
 class VectorImputerPredictStreamOp(BaseModelStreamOp):
     CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.vector.VectorImputerPredictStreamOp'
     OP_TYPE = 'FUNCTION'
@@ -930,6 +1235,15 @@ class VectorStandardScalerPredictStreamOp(BaseModelStreamOp):
         super(VectorStandardScalerPredictStreamOp, self).__init__(*args, **kwargs)
         pass
 
+    def setModelStreamFilePath(self, val):
+        return self._add_param('modelStreamFilePath', val)
+
+    def setModelStreamScanInterval(self, val):
+        return self._add_param('modelStreamScanInterval', val)
+
+    def setModelStreamStartTime(self, val):
+        return self._add_param('modelStreamStartTime', val)
+
     def setNumThreads(self, val):
         return self._add_param('numThreads', val)
 
@@ -1043,136 +1357,3 @@ class VectorToKvStreamOp(StreamOperator):
     def setReservedCols(self, val):
         return self._add_param('reservedCols', val)
 
-
-class VectorToTripleStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.dataproc.format.VectorToTripleStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(VectorToTripleStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setTripleColumnValueSchemaStr(self, val):
-        return self._add_param('tripleColumnValueSchemaStr', val)
-
-    def setVectorCol(self, val):
-        return self._add_param('vectorCol', val)
-
-    def setHandleInvalid(self, val):
-        return self._add_param('handleInvalid', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-
-class WhereStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sql.WhereStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(WhereStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setClause(self, val):
-        return self._add_param('clause', val)
-
-
-class WindowGroupByStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.sql.WindowGroupByStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(WindowGroupByStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectClause(self, val):
-        return self._add_param('selectClause', val)
-
-    def setSessionGap(self, val):
-        return self._add_param('sessionGap', val)
-
-    def setSlidingLength(self, val):
-        return self._add_param('slidingLength', val)
-
-    def setWindowLength(self, val):
-        return self._add_param('windowLength', val)
-
-    def setGroupByClause(self, val):
-        return self._add_param('groupByClause', val)
-
-    def setIntervalUnit(self, val):
-        return self._add_param('intervalUnit', val)
-
-    def setWindowType(self, val):
-        return self._add_param('windowType', val)
-
-
-class Word2VecPredictStreamOp(BaseModelStreamOp):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.nlp.Word2VecPredictStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(Word2VecPredictStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setSelectedCol(self, val):
-        return self._add_param('selectedCol', val)
-
-    def setModelStreamFilePath(self, val):
-        return self._add_param('modelStreamFilePath', val)
-
-    def setModelStreamScanInterval(self, val):
-        return self._add_param('modelStreamScanInterval', val)
-
-    def setModelStreamStartTime(self, val):
-        return self._add_param('modelStreamStartTime', val)
-
-    def setNumThreads(self, val):
-        return self._add_param('numThreads', val)
-
-    def setOutputCol(self, val):
-        return self._add_param('outputCol', val)
-
-    def setPredMethod(self, val):
-        return self._add_param('predMethod', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
-    def setWordDelimiter(self, val):
-        return self._add_param('wordDelimiter', val)
-
-
-class WriteTensorToImageStreamOp(StreamOperator):
-    CLS_NAME = 'com.alibaba.alink.operator.stream.image.WriteTensorToImageStreamOp'
-    OP_TYPE = 'FUNCTION'
-
-    def __init__(self, *args, **kwargs):
-        kwargs['CLS_NAME'] = self.CLS_NAME
-        kwargs['OP_TYPE'] = self.OP_TYPE
-        super(WriteTensorToImageStreamOp, self).__init__(*args, **kwargs)
-        pass
-
-    def setRelativeFilePathCol(self, val):
-        return self._add_param('relativeFilePathCol', val)
-
-    def setRootFilePath(self, val):
-        return self._add_param('rootFilePath', val)
-
-    def setTensorCol(self, val):
-        return self._add_param('tensorCol', val)
-
-    def setImageType(self, val):
-        return self._add_param('imageType', val)
-
-    def setReservedCols(self, val):
-        return self._add_param('reservedCols', val)
-
